@@ -1,5 +1,5 @@
 package YAML::Dumper::Base;
-$YAML::Dumper::Base::VERSION = '0.93';
+$YAML::Dumper::Base::VERSION = '0.94';
 use YAML::Mo;
 
 use YAML::Node;
@@ -106,33 +106,3 @@ sub bless {
 }
 
 1;
-
-=encoding UTF-8
-
-=head1 NAME
-
-YAML::Dumper::Base - Base class for YAML Dumper classes
-
-=head1 SYNOPSIS
-
-    package YAML::Dumper::Something;
-    use YAML::Dumper::Base -base;
-
-=head1 DESCRIPTION
-
-YAML::Dumper::Base is a base class for creating YAML dumper classes.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
