@@ -1,5 +1,5 @@
 package YAML::Loader::Base;
-$YAML::Loader::Base::VERSION = '0.93';
+$YAML::Loader::Base::VERSION = '0.94';
 use YAML::Mo;
 
 has load_code     => default => sub {0};
@@ -31,33 +31,3 @@ sub load {
 }
 
 1;
-
-=encoding UTF-8
-
-=head1 NAME
-
-YAML::Loader::Base - Base class for YAML Loader classes
-
-=head1 SYNOPSIS
-
-    package YAML::Loader::Something;
-    use YAML::Loader::Base -base;
-
-=head1 DESCRIPTION
-
-YAML::Loader::Base is a base class for creating YAML loader classes.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
